=======
Credits
=======

Development Lead
----------------

* Micah Johnson `@micahjohnson150 <http://github.com/micahjohnson150>`_

Contributors
------------

* Scott Havens `@scotthavens <http://github.com/scotthavens>`_
* Joachim Meyer `@jomey <https://github.com/jomey>`_
* Micah Sandusky `@micah-prime <http://github.com/micah-prime>`_
